@@ -138,9 +138,9 @@ bool Bayonne::loadPlugin(const char *path)
 	if(!prefix)
 		prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Plugins";
 #else
-        char prefixbuf[256];
 
 #ifdef	HAVE_TESTING
+	char prefixbuf[256];
         if(!prefix && provision_test && !strchr(path, '/'))
         {
                 snprintf(prefixbuf, sizeof(prefixbuf),
@@ -208,9 +208,10 @@ bool Bayonne::loadMonitor(const char *path)
 	if(!prefix)
 		prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Monitors";
 #else
-        char prefixbuf[256];
 
 #ifdef	HAVE_TESTING
+	char prefixbuf[256];
+
         if(!prefix && provision_test && !strchr(path, '/'))
         {
                 snprintf(prefixbuf, sizeof(prefixbuf),
@@ -280,7 +281,7 @@ bool Bayonne::matchDigits(const char *digits, const char *match, bool partial)
 {
 	unsigned len = strlen(match);
 	unsigned dlen = 0;
-	bool dflag = true, inc;
+	bool inc;
 	const char *d = digits;
 	char dbuf[32];
 
