@@ -1869,7 +1869,7 @@ protected:
 	calltype_t type;
 	event_t seizure;
 
-	Name *getScript(const char *scr);
+//	Name *getScript(const char *scr);
 
 	/**
 	 * Used to indicate commands which require dtmf handling to be
