@@ -439,6 +439,15 @@ void Driver::startDriver(void)
 		snprintf(cbuf, sizeof(cbuf), "%d SPEEX/%ld",
 			data_negotiate, info.rate);
 		break;
+	case g721ADPCM:
+		if(!data_negotiate)
+		{
+			data_negotiate = 5;
+			setValue("payload", "5");
+		}
+		snprintf(cbuf, sizeof(cbuf), "%d G726-32/%ld",
+			data_negotiate, info.rate);
+		break;
 	case gsmVoice:
 		if(!data_negotiate)
 		{
@@ -1513,6 +1522,10 @@ sip415:
 				session->data_payload = 8;
 				data_rtpmap = "PCMA/8000/1";
 				break;
+			case g721ADPCM:
+				session->data_payload = 5;
+				data_rtpmap = "G726_32/8000/1";
+				break;
 			case speexVoice:
 				session->data_payload = 97;
 				data_rtpmap = "SPEEX/8000/1";
@@ -1584,6 +1597,8 @@ sip415:
 						session->dtmf_payload = atoi(adp);
 						continue;
 					}
+					if(!strnicmp(tmp, "G721", 4))
+						tmp = "G726_32";
 					if(!strnicmp(tmp, data_rtpmap, strlen(tmp)))
 					{
 						audio_payload = adp;
