@@ -45,6 +45,13 @@ namespace sipdriver {
 using namespace ost;
 using namespace std;
 
+typedef	enum
+{
+	START_IMMEDIATE,
+	START_DELAYED,
+	START_ACTIVE
+}	starting_mode_t;
+
 struct dtmf2833
 {
 #if __BYTE_ORDER == __BIG_ENDIAN
@@ -103,10 +110,12 @@ protected:
 	bool exiting;
 	bool dtmf_inband;
 	bool data_filler;
+	bool send_immediate;
 	Level silence;
 	unsigned jitter;
 	timeout_t accept_timer;
 	timeout_t audio_timer;
+	starting_mode_t starting;
 
 public:
 	static Driver sip;		// plugin activation
@@ -168,12 +177,16 @@ public:
 	RTPStream(Session *session);
 	~RTPStream();
 
+	void newSession(void);
+	void endSession(void);
+
         void start(void);
 
 	void put2833(struct dtmf2833 *data);
         ssize_t putBuffer(Encoded data, size_t len);
         ssize_t getBuffer(Encoded data, size_t len);
 
+	void runActive(void);
         void run(void);
 	void peerAudio(Encoded encoded, bool linear);
 	void postAudio(Encoded encoded);
@@ -203,7 +216,7 @@ protected:
 	InetHostAddress local_address, remote_address;
 	tpport_t remote_port;
 	RTPStream *rtp;
-	bool update_pos;
+	bool update_pos, rtp_flag;
 	Linear peer_buffer;
 	AudioCodec *peer_codec;
 	uint8 dtmf_payload, data_payload;
@@ -264,6 +277,8 @@ public:
 
 	void sipHangup(void);
 
+	void sipRelease(void);
+
 	inline tpport_t getRemotePort(void)
 		{return remote_port;};
 
