@@ -38,7 +38,7 @@ static Keydata::Define driver[] = {
 Driver Driver::soundcard;
 
 Driver::Driver() :
-BayonneDriver(driver, KEYS, "soundcard", true)
+BayonneDriver(driver, KEYS, "soundcard", false)
 {
 	const char *cp;
 #ifdef	WIN32
@@ -91,14 +91,14 @@ void Driver::startDriver(void)
 
 #ifdef  WIN32
 	if(kb)
-	        keyboard = new Keyboard(this);
+	        keyboard = new Keyboard(ts_used);
 #else
         if(getppid() > 1 && kb)
-                keyboard = new Keyboard(this);
+                keyboard = new Keyboard(ts_used);
 #endif   
 
 	timeslot = ts_used;
-	new Session(0, device);
+	new Session(ts_used, device);
 	count = ts_used - timeslot;
 
 	msgport->start();
