@@ -34,8 +34,8 @@ Service::Service() :
 BayonneService(0, 0), Keydata(Bayonne::getKeypath(KEYS))
 {
 	static Keydata::Define defkeys[] = {
-	{"interface", "127.0.0.1:5555"},
-	{"gateway", "127.0.0.1:5556"},
+	{"interface", "127.0.0.1"},
+	{"port", "5555"},
 	{"secret", "pass"},
 	{NULL, NULL}};
 
@@ -63,25 +63,10 @@ void Service::stopService(void)
 
 void Service::run(void)
 {
-	tpport_t port;
-	Session *session;
-	char *abuf;
-	char *pnum;
-
-	if(Bayonne::provision_gateway)
-		abuf = (char *)getLast("gateway");
-	else
-		abuf = (char *)getLast("interface");
-
-	pnum = strrchr(abuf, ':');
-	if(pnum)
-		*(pnum++) = 0;
-	else
-		pnum = "5555";
-
-	port = atoi(pnum);
-	InetAddress addr(abuf);
+	InetAddress addr(getLast("interface"));
+	tpport_t port = atoi(getLast("port"));
 	TCPSocket tcp(addr, port);
+	Session *session;
 
 	active = true;
 	slog.debug("tcpmon service started");
