@@ -20,6 +20,21 @@ namespace server {
 using namespace ost;
 using namespace std;
 
+const char *Checks::chkSay(Line *line, ScriptImage *img)
+{
+	unsigned idx = 0;
+	if(getMember(line))
+		return "say has no members";
+
+	if(!getOption(line, &idx))
+		return "say requires at least one argument";
+
+	if(!useKeywords(line, "=file=voice=prefix=extension"))
+		return "invalid keywords for say";
+
+	return NULL;
+}		
+
 const char *Checks::chkConfig(Line *line, ScriptImage *img)
 {
 	Name *scr = img->getCurrent();
@@ -188,7 +203,7 @@ const char *Checks::chkTone(Line *line, ScriptImage *img)
 	if(getMember(line))
 		return "tone has no members";
 
-	if(!useKeywords(line, "=location=timeout=level"))
+	if(!useKeywords(line, "=location=timeout=level=name"))
 		return "unknown keyword for a tone";
 
 	if(getOption(line, &idx))
