@@ -95,6 +95,9 @@ static Keydata::Define libkeys[] = {
 	{"filesystem", VAR_FILES},
 	{"interface", "eth0"},
 	{"limit", "0"},
+	{"tts", "theta"},
+	{"voice", "female"},
+	{"ttslimit", "0"},
 	{NULL, NULL}};
 
 static Keydata::Define smtpkeys[] = {
@@ -682,7 +685,7 @@ retry:
 		goto retry;
 	}
 
-        if(!strnicmp(option, "-vv", 4))
+        if(!stricmp(option, "-vv"))
         {
 		Bayonne::provision_daemon = false;
                 keyserver.setValue("logging", "notice");
