@@ -41,6 +41,8 @@ ScriptRuntime()
                         (Check)&Checks::chkTone},
 		{"tone", false, (Method)&Methods::scrTonegen,
 			(Check)&Checks::chkTonegen},
+		{"teltone", false, (Method)&Methods::scrTone,
+			(Check)&Checks::chkTone},
                 {"callwait", false, (Method)&Methods::scrTone,
                         (Check)&Checks::chkTone},
                 {"callback", false, (Method)&Methods::scrTone,
@@ -132,6 +134,8 @@ ScriptRuntime()
 			(Check)&Checks::chkPathname},
 		{"play", false, (Method)&Methods::scrPlay,
 			(Check)&Checks::chkPathname},
+		{"say", false, (Method)&Methods::scrSay,
+			(Check)&Checks::chkSay},
         	{NULL, false, NULL, NULL}};
 
         trap("timeout", false);
