@@ -176,7 +176,6 @@ static void loading(void)
 	BayonneSysexec::allocate(keypaths.getLast("libexec"), bs, pri,
 		keypaths.getLast("modexec"));
 
-	runtime.setValue("definitions", "libexec.mac");
 #endif
         cp = keyserver.getLast("language");
         if(cp && (strlen(cp) == 2 || cp[2] == '_'))  
@@ -462,6 +461,7 @@ int main(int argc, char **argv)
 
 #ifdef	HAVE_LIBEXEC
 	runtime.setValue("definitions", "libexec.def");
+	runtime.setValue("definitions", "tts.def");
 #endif
 
 	if(argc == 2)
