@@ -115,6 +115,11 @@ private:
 	BayonneAudio *in;
 	bool completed;
 
+#ifdef	AUDIO_RATE_RESAMPLER
+	AudioResample *resampler;
+	Linear resample;
+#endif
+
 	void copyDirect(void);
 	void copyConvert(void);
 
@@ -220,6 +225,7 @@ public:
 	bool scrBGM(void);
 	bool scrList(void);
 	bool scrEcho(void);
+	bool scrSay(void);
 	bool scrPickup(void);
 	bool scrHangup(void);
 	bool scrWaitkey(void);
@@ -263,6 +269,7 @@ public:
 class Checks : public ScriptChecks, public Bayonne
 {
 public:
+	const char *chkSay(Line *line, ScriptImage *img);
         const char *chkEndinput(Line *line, ScriptImage *img); 
 	const char *chkBGM(Line *line, ScriptImage *img);
 	const char *chkWrite(Line *line, ScriptImage *img);
